@@ -5,44 +5,39 @@ use warnings;
 
 # ABSTRACT: A ProcPolicy that processes into references' values recursively
 
-our $VERSION = '1.111762'; # VERSION
+our $VERSION = '1.111810'; # VERSION
 
 use Moose;
 with 'DataFlow::Role::ProcPolicy';
 
 use namespace::autoclean;
 
-has '+handlers' => (
-    'default' => sub {
-        my $self         = shift;
-        my $type_handler = {
-            'SCALAR' => sub {
-                my ( $p, $item ) = @_;
-                return _handle_scalar_ref( _make_apply_ref( $self, $p ),
-                    $item );
-            },
-            'ARRAY' => sub {
-                my ( $p, $item ) = @_;
-                return _handle_array_ref( _make_apply_ref( $self, $p ), $item );
-            },
-            'HASH' => sub {
-                my ( $p, $item ) = @_;
-                return _handle_hash_ref( _make_apply_ref( $self, $p ), $item );
-            },
-            'CODE' => sub {
-                my ( $p, $item ) = @_;
-                return _handle_code_ref( _make_apply_ref( $self, $p ), $item );
-            },
-        };
-        return $type_handler;
-    },
-);
+sub _build_handlers {
+    my $self         = shift;
+    my $type_handler = {
+        'SCALAR' => sub {
+            my ( $p, $item ) = @_;
+            return _handle_scalar_ref( _make_apply_ref( $self, $p ), $item );
+        },
+        'ARRAY' => sub {
+            my ( $p, $item ) = @_;
+            return _handle_array_ref( _make_apply_ref( $self, $p ), $item );
+        },
+        'HASH' => sub {
+            my ( $p, $item ) = @_;
+            return _handle_hash_ref( _make_apply_ref( $self, $p ), $item );
+        },
+        'CODE' => sub {
+            my ( $p, $item ) = @_;
+            return _handle_code_ref( _make_apply_ref( $self, $p ), $item );
+        },
+    };
+    return $type_handler;
+}
 
-has '+default_handler' => (
-    'default' => sub {
-        return \&_handle_svalue;
-    },
-);
+sub _build_default_handler {
+    return \&_handle_svalue;
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -60,7 +55,7 @@ DataFlow::Policy::ProcessInto - A ProcPolicy that processes into references' val
 
 =head1 VERSION
 
-version 1.111762
+version 1.111810
 
 =head1 SEE ALSO
 
