@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A processor that writes data to a file
 
-our $VERSION = '1.111762'; # VERSION
+our $VERSION = '1.111810'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
@@ -22,18 +22,16 @@ has 'ors' => (
     'documentation' => 'Output record separator',
 );
 
-has '+p' => (
-    'default' => sub {
-        my $self = shift;
+sub _build_p {
+    my $self = shift;
 
-        return sub {
-            my $fh = $self->file;
-            local $\ = $self->ors if $self->has_ors;
-            print $fh $_;
-            return $_;
-        };
-    },
-);
+    return sub {
+        my $fh = $self->file;
+        local $\ = $self->ors if $self->has_ors;
+        print $fh $_;
+        return $_;
+    };
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -51,7 +49,7 @@ DataFlow::Proc::SimpleFileOutput - A processor that writes data to a file
 
 =head1 VERSION
 
-version 1.111762
+version 1.111810
 
 =head1 SEE ALSO
 
